PEL: Don't fix user specified action flags

Previously, the PEL object would never trust the action flags field
specified in the PEL registry and would always set some of the flags in
it itself based on a set of rules.

It turns out there are some cases where what the user needs doesn't
match the rules, so now only fix up the action flags if they weren't
specified in the registry and leave the flags alone if they were.

Most PELs in the registry should be able to leave out the action flags
field and let the PEL code set them.

Signed-off-by: Matt Spinler <spinler@us.ibm.com>
Change-Id: I80263d779c842acac042023c468b7e979ec7158c
diff --git a/extensions/openpower-pels/user_header.cpp b/extensions/openpower-pels/user_header.cpp
index 0e53acf..a687c55 100644
--- a/extensions/openpower-pels/user_header.cpp
+++ b/extensions/openpower-pels/user_header.cpp
@@ -116,8 +116,9 @@
     _problemDomain = 0;
     _problemVector = 0;
 
-    // These will be cleaned up later in pel_rules::check()
-    _actionFlags = entry.actionFlags.value_or(0);
+    // These will be set in pel_rules::check() if they're still
+    // at the default value.
+    _actionFlags = entry.actionFlags.value_or(actionFlagsDefault);
 
     _states = 0;